@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 
 use Readonly;
 
@@ -57,7 +57,7 @@ sub members_of {
 
         my $pkg = "Acme::MadokaMagica::TvMembers::$member_name";
         if (eval "require $pkg;1;"){
-            push @members,$pkg->new($line);
+            push @members,$pkg->new();
         }
     }
 
